@@ -449,10 +449,12 @@ sub rgb_to_color_name {
 	} else {
 		die "Bad number of arguments.";
 	}
+	#my ($r,$g,$b,$no_error) = @_;
 	# If alpha is found, then assume the color has not been defined
 	return;
 	for my $color (keys %$COLORS) {
 		next if $color =~ /_a\d+$/;
+		my $fetch_color = fetch_color($color);
 		my @crgb = $IM->rgb( fetch_color($color) );
 		if ($r == $crgb[0] &&	$g == $crgb[1] &&	$b == $crgb[2]) {
 	    return $color;
@@ -462,6 +464,7 @@ sub rgb_to_color_name {
 	fatal_error("color","bad_rgb_lookup",$r,$g,$b);
 }
 
+
 ################################################################
 # Fetch the color. If -randomcolor is defined, then the 
 # returned color will be a random RGB color unless it is one of the
@@ -488,18 +491,63 @@ sub fetch_color {
 	    return $color_table->{$color_name};
 		}
 	}
-	if (exists $color_table->{$color_name}) {
+	if (exists $COLORS->{$color_name}) {
 		stop_timer("colorfetch");
-		printdebug_group("color","fetch",$color_name,$color_table->{$color_name});
-		return $color_table->{$color_name};
-	} elsif ($color_table->{lc $color_name}) {
+		printdebug_group("color","fetch",$color_name,$COLORS->{$color_name});
+		return $COLORS->{$color_name};
+	} elsif ($COLORS->{lc $color_name}) {
 		my $lc_color = lc $color_name;
 		printwarning("Circos colors should be lowercase. You have asked for color [$color_name] and it was interpreted as [$lc_color]");
 		stop_timer("colorfetch");
-		return $color_table->{lc $color_name};
-	} elsif (my @rgb = validate_color($color_name,0)) {
-		allocate_color($color_name,\@rgb,$color_table,$im);
-		return $color_table->{$color_name};
+		return $COLORS->{lc $color_name};
+	} elsif (my @rgb = validate_rgb($color_name,0)) {
+		my $color = rgb_to_color_name(@rgb,1);
+		if (defined $color) {
+	    stop_timer("colorfetch");
+	    return $color_table->{$color};
+		} else {
+	    printdebug_group("color","dynamic allocation rgb",$color_name);
+	    allocate_color($color_name,\@rgb,$color_table,$im);
+	    stop_timer("colorfetch");
+	    return $color_table->{$color_name};
+		}
+	} elsif (my @rgb_hex = validate_hex($color_name,0)) {
+		my $color = rgb_to_color_name(@rgb_hex,1);
+		if (defined $color) {
+	    stop_timer("colorfetch");
+	    return $color_table->{$color};
+		} else {
+	    printdebug_group("color","dynamic allocation hex",$color_name);
+	    allocate_color($color_name,\@rgb_hex,$color_table,$im);
+	    stop_timer("colorfetch");
+	    return $color_table->{$color_name};
+		}
+	} elsif (my @hsv = validate_hsv($color_name,0)) {
+		my @rgb255   = hsv_to_rgb(@hsv);
+		my @rgb      = rgb_to_rgb255(\@rgb255);
+		my $color = rgb_to_color_name(@rgb,1);
+		if (defined $color) {
+	    stop_timer("colorfetch");
+	    return $color_table->{$color};
+		} else {
+	    printdebug_group("color","dynamic allocation rgb",$color_name);
+	    allocate_color($color_name,\@rgb,$color_table,$im);
+	    stop_timer("colorfetch");
+	    return $color_table->{$color_name};
+		}
+	} elsif (my @lch = validate_lch($color_name,0)) {
+		my @rgb = lch_to_rgb(@lch);
+		push @rgb, $lch[3] if @lch == 4;
+		my $color = rgb_to_color_name(@rgb,1);
+		if (defined $color) {
+	    stop_timer("colorfetch");
+	    return $color_table->{$color};
+		} else {
+	    printdebug_group("color","dynamic allocation rgb",$color_name);
+	    allocate_color($color_name,\@rgb,$color_table,$im);
+	    stop_timer("colorfetch");
+	    return $color_table->{$color_name};
+		}
 	} elsif (my $default_color = fetch_conf("default_color")) {
 		return $color_table->{$default_color};
 	} else {
@@ -507,7 +555,6 @@ sub fetch_color {
 	}
 }
 
-################################################################
 # Return a color object, depending on whether antialiasing is set or not.
 #
 # Antialiasing in GD works only for opaque colors.
@@ -522,10 +569,6 @@ sub aa_color {
 	}
 }
 
-################################################################
-# Find the first unallocated RGB color that we can use
-# as the transparent color. GD is stupid this way -- you actually
-# need to define a color first and then make it transparent :/ 
 sub find_transparent {
 	my @rgb = (0,0,0);
 	my $idx = 0;
@@ -538,8 +581,6 @@ sub find_transparent {
 	return @rgb;
 }
 
-################################################################
-# 
 sub color_to_list {
 	my $color = shift;
 	return if ! defined $color;
